<!doctype html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <title>JupyterLab</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
    <script id="jupyter-config-data" type="application/json">{
    {% for key, value in page_config.items() -%}
    "{{ key }}": "{{ value }}",
    {% endfor -%}
    "baseUrl": "{{ base_url }}",
    "wsUrl": "{{ ws_url }}"
  }</script>

  {% block favicon %}<link rel="shortcut icon" type="image/x-icon" href="{{ base_url }}static/base/images/favicon.ico">{% endblock %}

</head>
<body>

<script type="text/javascript">
  function _remove_token_from_url() {
    if (window.location.search.length <= 1) {
      return;
    }
    var search_parameters = window.location.search.slice(1).split('&');
    for (var i = 0; i < search_parameters.length; i++) {
      if (search_parameters[i].split('=')[0] === 'token') {
        // remote token from search parameters
        search_parameters.splice(i, 1);
        var new_search = '';
        if (search_parameters.length) {
          new_search = '?' + search_parameters.join('&');
        }
        var new_url = window.location.origin +
                      window.location.pathname +
                      new_search +
                      window.location.hash;
        window.history.replaceState({}, "", new_url);
        return;
      }
    }
  }
  _remove_token_from_url();
</script>

<script type="text/javascript" src="{{base_url}}lab/static/manifest.96c1324feeeb0d9f4d79.js"></script><script type="text/javascript" src="{{base_url}}lab/static/vendor.c615d5bc3e0c4398b45f.js"></script><script type="text/javascript" src="{{base_url}}lab/static/main.f769e66d9e353fed0521.js"></script></body>
</html>
